/* ide-langserv-util.h
 *
 * Copyright © 2017 Christian Hergert <chergert@redhat.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include "ide-version-macros.h"

#include "symbols/ide-symbol.h"

G_BEGIN_DECLS

IDE_AVAILABLE_IN_ALL
IdeSymbolKind ide_langserv_decode_symbol_kind     (guint kind);
IDE_AVAILABLE_IN_ALL
IdeSymbolKind ide_langserv_decode_completion_kind (guint kind);

G_END_DECLS
